@@ -268,10 +268,13 @@ class Worksheet(object):
             raise IncorrectCellLabel('(%s, %s)' % (row, col))
 
         div = col
-        column_label = str()
+        column_label = ''
 
         while div:
             (div, mod) = divmod(div, 26)
+            if mod == 0:
+                 mod = 26
+                 div -= 1
             column_label = chr(mod + self._MAGIC_NUMBER) + column_label
 
         label = '%s%s' % (column_label, row)
@@ -331,6 +334,9 @@ class Worksheet(object):
 
         # we return a whole rectangular region worth of cells, including
         # empties
+        if not rows:
+            return []
+            
         all_row_keys = chain.from_iterable(row.keys() for row in rows.values())
         rect_cols = range(1, max(all_row_keys) + 1)
         rect_rows = range(1, max(rows.keys()) + 1)
@@ -556,9 +562,10 @@ class Cell(object):
         cell_elem = element.find(_ns1('cell'))
         self._row = int(cell_elem.get('row'))
         self._col = int(cell_elem.get('col'))
+        self.input_value = cell_elem.get('inputValue')
 
         #: Value of the cell.
-        self.value = cell_elem.text
+        self.value = cell_elem.text or ''
 
     @property
     def row(self):
